import { values, flatten, map, cond, T, o, of } from 'ramda';
import isArray from './isArray';
import isObject from './isObject';

var recursiveArray = function recursiveArray(r) {
  return o(flatten, map(flattenValues))(r);
};

var recursiveObject = function recursiveObject(r) {
  return o(flattenValues, values)(r);
};
/**
 * Returns flatten values from object and array. Recursively.
 *
 * @func
 * @category Array, Object
 *
 * @param  {Array|Object} value
 * @return {Array} array of values
 *
 * @example
 *
 *        R_.flattenValues([
 *				'hi',
 *				{ foo: 'bar' },
 *				{ foo: 'hi' },
 *				{
 *					foo: {
 *						bar: ['cuuus', { foo: 'hi' }],
 *					},
 *				},
 *				['haha', 'hi'],
 *				['haha', { foo: 'hi' }],
 *			]) // ['hi','bar','hi','cuuus','hi','haha','hi','haha','hi']
 *
 */


var flattenValues =
/*#__PURE__*/
cond([[isArray, recursiveArray], [isObject, recursiveObject], [T, of]]);
export default flattenValues;